## Что это

Библиотека для работы с файлами и СУБД

## Установка через [PiPy](https://pypi.org/project/mg-file/)

```bash
pip install mg-file
```

[Документация](https://mg-file.readthedocs.io/ru/latest/)

